pub struct CreateMountOptions {
pub name: CompactString,
pub description: Option<CompactString>,
pub source: CompactString,
pub target: CompactString,
pub read_only: bool,
pub user_mountable: bool,
}Fields
name: CompactStringdescription: Option<CompactString>source: CompactStringtarget: CompactStringread_only: booluser_mountable: boolTrait Implementations
Sourceimpl ComposeSchema for CreateMountOptions
impl ComposeSchema for CreateMountOptions
Sourceimpl<'de> Deserialize<'de> for CreateMountOptions
impl<'de> Deserialize<'de> for CreateMountOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateMountOptions
impl ToSchema for CreateMountOptions
Sourceimpl Validate for CreateMountOptions
impl Validate for CreateMountOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateMountOptions
impl RefUnwindSafe for CreateMountOptions
impl Send for CreateMountOptions
impl Sync for CreateMountOptions
impl Unpin for CreateMountOptions
impl UnwindSafe for CreateMountOptions